@@ -1,19 +1,14 @@
 import os
 import requests
 import logging
-import configparser
 
-logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
+logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
 
-class ManageFiles():
-    def __init__(self):
-        config = configparser.ConfigParser()
-        config.sections()
-        config.read("broker_config.ini")
-        FMS_HOST = config.get('FMSConfig','FMS_HOST')
-        FMS_PORT = config.get('FMSConfig','FMS_PORT')
-        self.fms_host = FMS_HOST
-        self.fms_port = FMS_PORT
+class FilesManager():
+    def __init__(self, config):
+        print(config)
+        self.fms_host = config['FMS_HOST']
+        self.fms_port = config['FMS_PORT']
         self.fms_url = f"{self.fms_host}:{self.fms_port}"
         self.base_location = os.getcwd()
         
@@ -48,6 +43,3 @@ class ManageFiles():
         logging.warning(f"File Deleted Successfully {file_key}.{ext}")
         return f"File Deleted Successfully {file_key}.{ext}"
 
-cls = ManageFiles()
-
-
