@@ -6,10 +6,8 @@ import os
 import logging
 import configparser
 
-RABBIT_USER = os.getenv('RABBIT_USER') or 'admin'
-RABBIT_PASSWORD = os.getenv('RABBIT_PASSWORD') or 'admin'
-RABBIT_HOST = os.getenv('RABBIT_HOST') or '10.1.0.5'
-RABBIT_PORT = os.getenv('RABBIT_PORT') or '5672'
+
+
 
 logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
 logging.getLogger("pika").setLevel(logging.ERROR)
@@ -17,23 +15,16 @@ logging.getLogger("pika").setLevel(logging.ERROR)
 class consumer_class(): 
 
 
-    def __init__(self, service_name, handler):
-        config = configparser.ConfigParser()
-        config.sections()
-        config.read("broker_config.ini")
-        host = config.get('FMSConfig','FMS_HOST')
-        port = config.get('FMSConfig','FMS_HOST')
-
-        EXCHANGE_NAME = os.getenv('EXCHANGE_NAME') or 'pre_production'
-        NEW_JOBS_ROUTING_KEY = os.getenv('NEW_JOBS_ROUTING_KEY') or 'dispatcher.job.ready_for_'
-        SUCCESSFUL_JOB_ROUTING_KEY = os.getenv('SUCCESSFUL_JOB_ROUTING_KEY') or '.job.complete'
-        FAILED_JOB_ROUTING_KEY = os.getenv('FAILED_JOB_ROUTING_KEY') or '.job.failed'
-        
-        self.exchange_name = EXCHANGE_NAME
+    def __init__(self, service_name, handler, config):
+        self.rabbit_user = config['RABBIT_USER']
+        self.rabbit_password = config['RABBIT_PASSWORD']
+        self.rabbit_host = config['RABBIT_HOST'] 
+        self.rabbit_port = config['RABBIT_PORT']     
+        self.exchange_name = config['EXCHANGE_NAME']
         self.qeue_name = service_name + '_jobs'
-        self.new_jobs_routing_key = NEW_JOBS_ROUTING_KEY + service_name
-        self.successful_job_routing_key = service_name + SUCCESSFUL_JOB_ROUTING_KEY
-        self.failed_job_routing_key = service_name + FAILED_JOB_ROUTING_KEY
+        self.new_jobs_routing_key = config['NEW_JOBS_ROUTING_KEY']  + service_name
+        self.successful_job_routing_key = service_name + config['SUCCESSFUL_JOB_ROUTING_KEY']
+        self.failed_job_routing_key = service_name + config['FAILED_JOB_ROUTING_KEY']
         self.handler = handler
         self._conn = None
         self._channel = None
@@ -42,10 +33,10 @@ class consumer_class():
     
     def connect(self):
         try:
-            credentials = pika.PlainCredentials(RABBIT_USER, RABBIT_PASSWORD)
+            credentials = pika.PlainCredentials(self.rabbit_user, self.rabbit_password)
 
-            parameters = pika.ConnectionParameters(RABBIT_HOST,
-                                    int(RABBIT_PORT),
+            parameters = pika.ConnectionParameters(self.rabbit_host,
+                                    int(self.rabbit_port),
                                     '/',
                                     credentials)
             self._conn = pika.BlockingConnection(parameters)
